pub struct Claim {
pub outcome: Outcome,
pub status: ClaimStatus,
/* private fields */
}Expand description
Outcome claim whose achieved/readiness status cannot exist without supporting evidence.
Fields
outcome: OutcomeOutcome used by staff to prepare training assignment, package, progress, or parent-summary review.
status: ClaimStatusStatus used by staff to prepare training assignment, package, progress, or parent-summary review.
Implementations
Sourceimpl Claim
impl Claim
Sourcepub fn from_evidence(value: ClaimEvidence) -> Result<Self>
pub fn from_evidence(value: ClaimEvidence) -> Result<Self>
Builds this training value from evidence data.
Sourcepub fn evidence(&self) -> &[EvidenceId]
pub fn evidence(&self) -> &[EvidenceId]
Returns the trainer/source evidence that supports this outcome claim.
Sourcepub fn milestones(&self) -> &[Id]
pub fn milestones(&self) -> &[Id]
Returns the milestones value used by training assignment, progress, package, or parent-summary review.