pub struct Documentation {
pub documentation_id: OutcomeDocumentationId,
pub enrollment_id: Id,
pub pet_id: PetId,
pub location_id: LocationId,
/* private fields */
}Expand description
Training outcome documentation packet for customer/account history and manager review.
Fields
documentation_id: OutcomeDocumentationIdDocumentation identifier used by staff to prepare training assignment, package, progress, or parent-summary review.
enrollment_id: IdEnrollment identifier used by staff to prepare training assignment, package, progress, or parent-summary review.
pet_id: PetIdPet receiving the training service or parent-facing progress update.
location_id: LocationIdLocation identifier used by staff to prepare training assignment, package, progress, or parent-summary review.
Implementations
Sourceimpl Documentation
impl Documentation
Sourcepub fn builder() -> DocumentationBuilder
pub fn builder() -> DocumentationBuilder
Starts a validated builder for this training documentation or progress packet.
Sourcepub fn claims(&self) -> &[Claim]
pub fn claims(&self) -> &[Claim]
Returns the claims value used by training assignment, progress, package, or parent-summary review.
Sourcepub fn review(&self) -> &OutcomeReviewState
pub fn review(&self) -> &OutcomeReviewState
Returns the review value used by training assignment, progress, package, or parent-summary review.
Sourcepub fn member_facing_boundary(&self) -> MemberFacingBoundary
pub fn member_facing_boundary(&self) -> MemberFacingBoundary
Returns whether this training outcome can appear in parent-facing copy or must remain internal.