pub struct Documentation {
pub documentation_id: OutcomeDocumentationId,
pub enrollment_id: Id,
pub pet_id: PetId,
pub location_id: LocationId,
/* private fields */
}Expand description
Training outcome documentation packet for customer/account history and manager review.
Fields
documentation_id: OutcomeDocumentationIdSource-derived documentation id carried by this training contract.
enrollment_id: IdSource-derived enrollment id carried by this training contract.
pet_id: PetIdPet receiving the grooming or care service.
location_id: LocationIdSource-derived location id carried by this training contract.
Implementations
Sourceimpl Documentation
impl Documentation
Sourcepub fn builder() -> DocumentationBuilder
pub fn builder() -> DocumentationBuilder
Starts a validated builder for this training documentation or progress packet.
Sourcepub fn claims(&self) -> &[Claim]
pub fn claims(&self) -> &[Claim]
Returns the claims evidence recorded on this training contract.
Sourcepub fn review(&self) -> &OutcomeReviewState
pub fn review(&self) -> &OutcomeReviewState
Returns the review evidence recorded on this training contract.
Sourcepub fn member_facing_boundary(&self) -> MemberFacingBoundary
pub fn member_facing_boundary(&self) -> MemberFacingBoundary
Returns the member facing boundary evidence recorded on this training contract.